@@ -77,11 +77,23 @@ class ModelConverter:
     def _call_tf_op_lambda_layer(
             self, converted_layer: TFOpLambda, node_input_tensors: Union[KerasTensor, List[KerasTensor]],
             current_layer: TFOpLambda, transform_signal: bool) -> KerasTensor:
-        if isinstance(node_input_tensors, list):
-            return converted_layer(*node_input_tensors)
 
         call_args = current_layer.inbound_nodes[0].call_args
         call_kwargs = current_layer.inbound_nodes[0].call_kwargs
+        last_input_axis_index = len(current_layer.input_shape) - 1
+        if current_layer.symbol == 'stack':
+            if transform_signal:
+                transformed_axis = self._convert_axis_channel(call_kwargs['axis'], last_input_axis_index)
+                call_kwargs['axis'] = transformed_axis
+            return converted_layer(node_input_tensors, *current_layer.inbound_nodes[0].call_args[2:],
+                                   **current_layer.inbound_nodes[0].call_kwargs)
+
+        if isinstance(node_input_tensors, list) and current_layer.symbol != 'stack':
+            if current_layer.symbol == 'stack':
+                return converted_layer(node_input_tensors, *current_layer.inbound_nodes[0].call_args[2:],
+                                       **current_layer.inbound_nodes[0].call_kwargs)
+            return converted_layer(*node_input_tensors)
+
         if transform_signal:
             if isinstance(converted_layer, SlicingOpLambda):
                 slice_spec = call_kwargs.get('slice_spec')
@@ -93,11 +105,9 @@ class ModelConverter:
                     converted_slice_spec = [slice_spec[0]] + slice_spec[2:] + [slice_spec[1]]
                 return converted_layer(node_input_tensors, slice_spec=converted_slice_spec)
             elif converted_layer.symbol == 'compat.v1.gather':
-                last_input_axis_index = len(current_layer.input_shape) - 1
                 transformed_axis = self._convert_axis_channel(call_kwargs['axis'], last_input_axis_index)
                 call_kwargs['axis'] = transformed_axis
             elif converted_layer.symbol == 'expand_dims':
-                last_input_axis_index = len(current_layer.input_shape) - 1
                 transformed_axis = self._convert_axis_channel(call_args[1:][0], last_input_axis_index)
                 call_args = (call_args[0], transformed_axis)
 
